==> claromentis-framework-9.6.6-26891208.zip: web/intranet/documents/classes/Event/DocumentEventType.php <==
<?php
namespace Claromentis\Documents\Event;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array();


class DocumentEventType
{
    
    
    const PRE_ADD_DOCUMENT = 'documents.pre_add_document';
    const ADD_DOCUMENT = 'documents.add_document';
    const PRE_UPDATE_DOCUMENT = 'documents.pre_update_document';
    const UPDATE_DOCUMENT = 'documents.update_document';
    const PRE_MOVE_DOCUMENT = 'documents.pre_move_document';
    const MOVE_DOCUMENT = 'documents.move_document';
    const PRE_DELETE_DOCUMENT = 'documents.pre_delete_document';
    const DELETE_DOCUMENT = 'documents.delete_document';
    const PRE_CHECKOUT_DOCUMENT = 'documents.pre_checkout_document';
    const CHECKOUT_DOCUMENT = 'documents.checkout_document';
    const PRE_CHECKIN_DOCUMENT = 'documents.pre_checkin_document';
    const CHECKIN_DOCUMENT = 'documents.checkin_document';
    const PRE_VIEW_DOCUMENT = 'documents.pre_view_document';
    const VIEW_DOCUMENT = 'documents.view_document';
    const PRE_DOWNLOAD_DOCUMENT = 'documents.pre_download_document';
    const DOWNLOAD_DOCUMENT = 'documents.download_document';
    
    
    const PRE_ADD_FOLDER = 'documents.pre_add_folder';
    const ADD_FOLDER = 'documents.add_folder';
    const PRE_UPDATE_FOLDER = 'documents.pre_update_folder';
    const UPDATE_FOLDER = 'documents.update_folder';
    const PRE_DELETE_FOLDER = 'documents.pre_delete_folder';
    const DELETE_FOLDER = 'documents.delete_folder';
    const FOLDER_CONTENT_CHANGE = 'documents.folder_content_change';
    
    
    const PRE_UPDATE_PERMISSIONS = 'documents.pre_update_permissions';
    const UPDATE_PERMISSIONS = 'documents.update_permissions';
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/documents/classes/Event/DocumentEventType.php <==
<?php
namespace Claromentis\Documents\Event;

$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array();


class DocumentEventType
{
    
    
    const PRE_ADD_DOCUMENT = 'documents.pre_add_document';
    const ADD_DOCUMENT = 'documents.add_document';
    const PRE_UPDATE_DOCUMENT = 'documents.pre_update_document';
    const UPDATE_DOCUMENT = 'documents.update_document';
    const PRE_MOVE_DOCUMENT = 'documents.pre_move_document';
    const MOVE_DOCUMENT = 'documents.move_document';
    const PRE_DELETE_DOCUMENT = 'documents.pre_delete_document';
    const DELETE_DOCUMENT = 'documents.delete_document';
    const PRE_CHECKOUT_DOCUMENT = 'documents.pre_checkout_document';
    const CHECKOUT_DOCUMENT = 'documents.checkout_document';
    const PRE_CHECKIN_DOCUMENT = 'documents.pre_checkin_document';
    const CHECKIN_DOCUMENT = 'documents.checkin_document';
    const PRE_VIEW_DOCUMENT = 'documents.pre_view_document';
    const VIEW_DOCUMENT = 'documents.view_document';
    const PRE_DOWNLOAD_DOCUMENT = 'documents.pre_download_document';
    const DOWNLOAD_DOCUMENT = 'documents.download_document';
    
    
    const PRE_ADD_FOLDER = 'documents.pre_add_folder';
    const ADD_FOLDER = 'documents.add_folder';
    const PRE_UPDATE_FOLDER = 'documents.pre_update_folder';
    const UPDATE_FOLDER = 'documents.update_folder';
    const PRE_DELETE_FOLDER = 'documents.pre_delete_folder';
    const DELETE_FOLDER = 'documents.delete_folder';
    const FOLDER_CONTENT_CHANGE = 'documents.folder_content_change';
    
    
    const PRE_UPDATE_PERMISSIONS = 'documents.pre_update_permissions';
    const UPDATE_PERMISSIONS = 'documents.update_permissions';
}
